@@ -1,4 +1,4 @@
-database_file = """
+database_file = r"""
 CREATE TABLE IF NOT EXISTS guild_settings(
     guild_id BIGINT PRIMARY KEY,
     prefix TEXT
